@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,19 +32,11 @@
 #define _SV_HEADBAR_CXX
 #include <svtools/headbar.hxx>
 #include <tools/debug.hxx>
-#ifndef _TOOLS_LIST_HXX
 #include <tools/list.hxx>
-#endif
 
-#ifndef _VCL_APP_HXX
 #include <vcl/svapp.hxx>
-#endif
-#ifndef _VCL_HELP_HXX
 #include <vcl/help.hxx>
-#endif
-#ifndef _VCL_IMAGE_HXX
 #include <vcl/image.hxx>
-#endif
 #include <com/sun/star/accessibility/XAccessible.hpp>
 
 // =======================================================================
@@ -1651,3 +1644,4 @@ void HeaderBar::SetAccessible( ::com::sun::star::uno::Reference< ::com::sun::sta
     mxAccessible = _xAccessible;
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
