@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,7 +29,6 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_svtools.hxx"
 
-#include <vos/macros.hxx>
 #include <vcl/bmpacc.hxx>
 #include <tools/poly.hxx>
 #include <vcl/outdev.hxx>
@@ -2380,3 +2380,4 @@ void GraphicObject::ImplTransformBitmap( BitmapEx& 			rBmpEx,
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
