@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,13 +36,9 @@
 #include <saldata.hxx>
 #include <saldisp.hxx>
 
-#ifndef _SV_SALGDI_HXX
 #include <salgdi.h>
-#endif
 
-#ifndef _SV_SALGDI_HXX
 #include <salframe.h>
-#endif
 #include <vcl/settings.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <plugins/kde/kdedata.hxx>
@@ -1834,6 +1831,8 @@ void KDESalFrame::UpdateSettings( AllSettings& rSettings )
     StyleSettings aStyleSettings( rSettings.GetStyleSettings() );
     bool bSetTitleFont = false;
 
+    aStyleSettings.SetToolbarIconSize( STYLE_TOOLBAR_ICONSIZE_LARGE );
+
     // WM settings
     KConfig *pConfig = KGlobal::config();
     if ( pConfig )
@@ -2115,3 +2114,5 @@ void KDEData::deInitNWF()
     // We have to destroy the style early
     kapp->setStyle( NULL );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
